/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.tasks.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Task.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Tasks API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Task extends GenericJson {

  /**
   * Completion date of the task (as a RFC 3339 timestamp). This field is omitted if the task has
   * not been completed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime completed;

  /**
   * Flag indicating whether the task has been deleted. The default if False.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean deleted;

  /**
   * Due date of the task (as a RFC 3339 timestamp). Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime due;

  /**
   * ETag of the resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * Flag indicating whether the task is hidden. This is the case if the task had been marked
   * completed when the task list was last cleared. The default is False. This field is read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean hidden;

  /**
   * Task identifier.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Type of the resource. This is always "tasks#task".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Collection of links. This collection is read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Links> links;

  static {
    // hack to force ProGuard to consider Links used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Links.class);
  }

  /**
   * Notes describing the task. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String notes;

  /**
   * Parent task identifier. This field is omitted if it is a top-level task. This field is read-
   * only. Use the "move" method to move the task under a different parent or to the top level.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String parent;

  /**
   * String indicating the position of the task among its sibling tasks under the same parent task
   * or at the top level. If this string is greater than another task's corresponding position
   * string according to lexicographical ordering, the task is positioned after the other task under
   * the same parent task (or at the top level). This field is read-only. Use the "move" method to
   * move the task to another position.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String position;

  /**
   * URL pointing to this task. Used to retrieve, update, or delete this task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Status of the task. This is either "needsAction" or "completed".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Title of the task.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * Last modification time of the task (as a RFC 3339 timestamp).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * Completion date of the task (as a RFC 3339 timestamp). This field is omitted if the task has
   * not been completed.
   * The value returned may be {@code null}.
   */
  public DateTime getCompleted() {
    return completed;
  }

  /**
   * Completion date of the task (as a RFC 3339 timestamp). This field is omitted if the task has
   * not been completed.
   * The value set may be {@code null}.
   */
  public Task setCompleted(DateTime completed) {
    this.completed = completed;
    return this;
  }

  /**
   * Flag indicating whether the task has been deleted. The default if False.
   * The value returned may be {@code null}.
   */
  public Boolean getDeleted() {
    return deleted;
  }

  /**
   * Flag indicating whether the task has been deleted. The default if False.
   * The value set may be {@code null}.
   */
  public Task setDeleted(Boolean deleted) {
    this.deleted = deleted;
    return this;
  }

  /**
   * Due date of the task (as a RFC 3339 timestamp). Optional.
   * The value returned may be {@code null}.
   */
  public DateTime getDue() {
    return due;
  }

  /**
   * Due date of the task (as a RFC 3339 timestamp). Optional.
   * The value set may be {@code null}.
   */
  public Task setDue(DateTime due) {
    this.due = due;
    return this;
  }

  /**
   * ETag of the resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * ETag of the resource.
   * The value set may be {@code null}.
   */
  public Task setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * Flag indicating whether the task is hidden. This is the case if the task had been marked
   * completed when the task list was last cleared. The default is False. This field is read-only.
   * The value returned may be {@code null}.
   */
  public Boolean getHidden() {
    return hidden;
  }

  /**
   * Flag indicating whether the task is hidden. This is the case if the task had been marked
   * completed when the task list was last cleared. The default is False. This field is read-only.
   * The value set may be {@code null}.
   */
  public Task setHidden(Boolean hidden) {
    this.hidden = hidden;
    return this;
  }

  /**
   * Task identifier.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Task identifier.
   * The value set may be {@code null}.
   */
  public Task setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Type of the resource. This is always "tasks#task".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Type of the resource. This is always "tasks#task".
   * The value set may be {@code null}.
   */
  public Task setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Collection of links. This collection is read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Links> getLinks() {
    return links;
  }

  /**
   * Collection of links. This collection is read-only.
   * The value set may be {@code null}.
   */
  public Task setLinks(java.util.List<Links> links) {
    this.links = links;
    return this;
  }

  /**
   * Notes describing the task. Optional.
   * The value returned may be {@code null}.
   */
  public String getNotes() {
    return notes;
  }

  /**
   * Notes describing the task. Optional.
   * The value set may be {@code null}.
   */
  public Task setNotes(String notes) {
    this.notes = notes;
    return this;
  }

  /**
   * Parent task identifier. This field is omitted if it is a top-level task. This field is read-
   * only. Use the "move" method to move the task under a different parent or to the top level.
   * The value returned may be {@code null}.
   */
  public String getParent() {
    return parent;
  }

  /**
   * Parent task identifier. This field is omitted if it is a top-level task. This field is read-
   * only. Use the "move" method to move the task under a different parent or to the top level.
   * The value set may be {@code null}.
   */
  public Task setParent(String parent) {
    this.parent = parent;
    return this;
  }

  /**
   * String indicating the position of the task among its sibling tasks under the same parent task
   * or at the top level. If this string is greater than another task's corresponding position
   * string according to lexicographical ordering, the task is positioned after the other task under
   * the same parent task (or at the top level). This field is read-only. Use the "move" method to
   * move the task to another position.
   * The value returned may be {@code null}.
   */
  public String getPosition() {
    return position;
  }

  /**
   * String indicating the position of the task among its sibling tasks under the same parent task
   * or at the top level. If this string is greater than another task's corresponding position
   * string according to lexicographical ordering, the task is positioned after the other task under
   * the same parent task (or at the top level). This field is read-only. Use the "move" method to
   * move the task to another position.
   * The value set may be {@code null}.
   */
  public Task setPosition(String position) {
    this.position = position;
    return this;
  }

  /**
   * URL pointing to this task. Used to retrieve, update, or delete this task.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * URL pointing to this task. Used to retrieve, update, or delete this task.
   * The value set may be {@code null}.
   */
  public Task setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Status of the task. This is either "needsAction" or "completed".
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * Status of the task. This is either "needsAction" or "completed".
   * The value set may be {@code null}.
   */
  public Task setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * Title of the task.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * Title of the task.
   * The value set may be {@code null}.
   */
  public Task setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * Last modification time of the task (as a RFC 3339 timestamp).
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * Last modification time of the task (as a RFC 3339 timestamp).
   * The value set may be {@code null}.
   */
  public Task setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * Model definition for TaskLinks.
   */
  public static final class Links extends GenericJson {

    /**
     * The description. In HTML speak: Everything between  and .
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String description;

    /**
     * The URL.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String link;

    /**
     * Type of the link, e.g. "email".
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The description. In HTML speak: Everything between  and .
     * The value returned may be {@code null}.
     */
    public String getDescription() {
      return description;
    }

    /**
     * The description. In HTML speak: Everything between  and .
     * The value set may be {@code null}.
     */
    public Links setDescription(String description) {
      this.description = description;
      return this;
    }

    /**
     * The URL.
     * The value returned may be {@code null}.
     */
    public String getLink() {
      return link;
    }

    /**
     * The URL.
     * The value set may be {@code null}.
     */
    public Links setLink(String link) {
      this.link = link;
      return this;
    }

    /**
     * Type of the link, e.g. "email".
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * Type of the link, e.g. "email".
     * The value set may be {@code null}.
     */
    public Links setType(String type) {
      this.type = type;
      return this;
    }

  }

}
